@@ -379,6 +379,9 @@ class Particles():
         # initialize the walk_data
         self.walk_data = None
 
+        # create weights - this might take a bit of time for large domains
+        lw.make_weight(self)
+
     # function to clear walk data if you've made a mistake while generating it
     def clear_walk_data(self):
         """Manually reset self.walk_data back to None."""
@@ -512,8 +515,7 @@ class Particles():
             start_times = prev_times + start_times
 
         # determine the new total number of particles we have now
-        # additive in the event we are running the generate multiple times
-        self.Np_tracer += Np_tracer
+        self.Np_tracer = len(start_xindices)
 
         # store information in the init_walk_data dictionary and return it
         init_walk_data['xinds'] = start_xindices
